# frozen_string_literal: true

require 'test_helper'

describe 'SpreadToBanchmark#new' do
  it 'populate bonds when file is correct' do
    c1 = File.join(File.dirname(__FILE__), '../fixtures/c1.csv')
    spread_to_benchmark = BondCalculator::SpreadToBenchmark.new(c1)

    assert !spread_to_benchmark.bonds.nil?
    assert spread_to_benchmark.bonds.size > 1
  end
  it 'error when file is wrong' do
    assert_raises(Errno::ENOENT) { BondCalculator::SpreadToBenchmark.new('') }
  end
end

describe 'SpreadToBanchmark#calculate' do
  c1 = File.join(File.dirname(__FILE__), '../fixtures/c1.csv')
  let(:spread_to_banchmark) { BondCalculator::SpreadToBenchmark.new(c1) }

  it 'return list  with bond_name and spread to curve' do
    response = spread_to_banchmark.calculate

    assert !response.nil?
    assert !response.empty?

    first = response.first
    assert_equal first[:bond_name], 'C1'
    assert_equal first[:benchmark_name], 'G1'
    assert_equal first[:spread_to_benchmark], 1.6
  end
end
