# frozen_string_literal: true

require 'test_helper'

describe 'SpreadToCurve#new' do
  it 'populate bonds when file is right' do
    c2 = File.join(File.dirname(__FILE__), '../fixtures/c2.csv')
    spread_to_curve = BondCalculator::SpreadToCurve.new(c2)

    assert !spread_to_curve.bonds.nil?
    assert !spread_to_curve.bonds.empty?
  end
  it 'error when file is wrong' do
    assert_raises(Errno::ENOENT) { BondCalculator::SpreadToCurve.new('') }
  end
end

describe 'SpreadToCurve#calculate' do
  c2 = File.join(File.dirname(__FILE__), '../fixtures/c2.csv')
  let(:spread_to_curve) { BondCalculator::SpreadToCurve.new(c2) }

  it 'return list  with bond_name and spread to curve' do
    response = spread_to_curve.calculate

    response.each do |r|
      assert !r[:bond_name].nil?
      assert !r[:spread_to_curve].nil?
    end

    assert !response.nil?
    assert !response.empty?

    first = response.first
    assert_equal first[:bond_name], 'C1'
    assert_equal first[:spread_to_curve], 1.43
  end
end
